@@ -27,13 +27,15 @@
 #endif
 
 #include "button.h"
-#include "enums.h"
-#include "click-action.h"
 
 #include <glib/gi18n-lib.h>
 #include <gdk/gdk.h>
 #include <math.h>
 
+#include "enums.h"
+#include "click-action.h"
+#include "image.h"
+
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardButton,
 				xfdashboard_button,
@@ -663,7 +665,7 @@ static void _xfdashboard_button_on_mapped_changed(XfdashboardButton *self,
 		ClutterImage	*image;
 
 		/* Set icon image */
-		image=xfdashboard_get_image_for_icon_name(priv->iconName, priv->iconSize);
+		image=xfdashboard_image_new_for_icon_name(priv->iconName, priv->iconSize);
 		clutter_actor_set_content(priv->actorIcon, CLUTTER_CONTENT(image));
 		g_object_unref(image);
 
@@ -1616,7 +1618,7 @@ void xfdashboard_button_set_icon(XfdashboardButton *self, const gchar *inIconNam
 		if(CLUTTER_ACTOR_IS_MAPPED(self))
 		{
 			/* Actor is mapped so we cannot defer loading and setting image */
-			image=xfdashboard_get_image_for_icon_name(priv->iconName, priv->iconSize);
+			image=xfdashboard_image_new_for_icon_name(priv->iconName, priv->iconSize);
 			clutter_actor_set_content(priv->actorIcon, CLUTTER_CONTENT(image));
 			g_object_unref(image);
 
@@ -1697,7 +1699,7 @@ void xfdashboard_button_set_icon_size(XfdashboardButton *self, gint inSize)
 		{
 			ClutterImage		*image;
 
-			image=xfdashboard_get_image_for_icon_name(priv->iconName, priv->iconSize);
+			image=xfdashboard_image_new_for_icon_name(priv->iconName, priv->iconSize);
 			clutter_actor_set_content(priv->actorIcon, CLUTTER_CONTENT(image));
 			g_object_unref(image);
 		}
