@@ -37,9 +37,9 @@
 
 #include "button.h"
 #include "stage.h"
-#include "utils.h"
 #include "click-action.h"
 #include "window-content.h"
+#include "image.h"
 
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardLiveWindow,
@@ -220,7 +220,7 @@ static void _xfdashboard_live_window_on_icon_changed(XfdashboardLiveWindow *self
 	if(inWindow!=priv->window) return;
 
 	/* Set new icon in title actor */
-	icon=xfdashboard_get_image_for_pixbuf(xfdashboard_window_tracker_window_get_icon(inWindow));
+	icon=xfdashboard_image_new_for_pixbuf(xfdashboard_window_tracker_window_get_icon(inWindow));
 	xfdashboard_button_set_icon_image(XFDASHBOARD_BUTTON(priv->actorTitle), icon);
 	g_object_unref(icon);
 }
