@@ -25,13 +25,13 @@
 #include "config.h"
 #endif
 
+#include "windows-view.h"
+
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
-#include "windows-view.h"
 #include "live-window.h"
 #include "scaled-table-layout.h"
-#include "utils.h"
 #include "stage.h"
 #include "application.h"
 #include "view.h"
@@ -39,6 +39,8 @@
 #include "quicklaunch.h"
 #include "application-button.h"
 #include "window-tracker.h"
+#include "image.h"
+#include "utils.h"
 
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardWindowsView,
@@ -355,7 +357,7 @@ static void _xfdashboard_windows_view_on_drag_begin(ClutterDragAction *inAction,
 
 	/* Create a application icon for drag handle */
 	windowIcon=xfdashboard_window_tracker_window_get_icon(xfdashboard_live_window_get_window(liveWindow));
-	image=xfdashboard_get_image_for_pixbuf(windowIcon);
+	image=xfdashboard_image_new_for_pixbuf(windowIcon);
 
 	dragHandle=xfdashboard_background_new();
 	clutter_actor_set_position(dragHandle, inStageX, inStageY);
